@@ -79,7 +79,7 @@
   t
   "The order to display Jira comments."
   :type '(choice (const :tag "Newest first" t)
-                 (const :tag "Oldest first" nil))
+          (const :tag "Oldest first" nil))
   :group 'jira)
 
 (defcustom jira-detail-reuse-buffer
@@ -310,7 +310,9 @@ like \"*Jira Issue Detail: [PROJ-123]*\"."
               (magit-insert-heading "🔗 Subtasks")
               (magit-insert-section-body
 		(seq-doseq (subtask subtasks)
-                  (jira-detail--format-issue-entry subtask)))
+                  (let ((subtask-key (alist-get 'key subtask)))
+                    (magit-insert-section (jira-subtask-section subtask-key nil)
+                      (jira-detail--format-issue-entry subtask)))))
               (insert "\n"))))))))
 
 (defun jira-detail--get-issue-buffer (key)
@@ -367,10 +369,58 @@ This is a shared function used by both subtasks and linked issues."
 
 (defun jira-detail--format-linked-issue (issue link-type direction)
   "Format a single linked ISSUE with LINK-TYPE and DIRECTION."
-  (let* ((link-text (if (string= direction "outward")
+  (let* ((issue-key (alist-get 'key issue))
+         (link-text (if (string= direction "outward")
                         (alist-get 'outward link-type)
                       (alist-get 'inward link-type))))
-    (jira-detail--format-issue-entry issue (or link-text "[Unknown link type]"))))
+    (magit-insert-section (jira-linked-issue-section issue-key nil)
+      (jira-detail--format-issue-entry issue (or link-text "[Unknown link type]")))))
+
+(defun jira-detail--open-related-issue-at-point (section-type)
+  "Open the related issue at point in the detail view.
+SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
+  (interactive)
+  (when-let ((issue-key (magit-section-value-if section-type)))
+    (jira-detail-show-issue issue-key)))
+
+(defun jira-detail--open-related-issue-in-browser (section-type)
+  "Open the related issue at point in the browser.
+SECTION-TYPE should be `jira-subtask-section' or `jira-linked-issue-section'."
+  (interactive)
+  (when-let ((issue-key (magit-section-value-if section-type)))
+    (jira-actions-open-issue issue-key)))
+
+(defun jira-detail--related-issue-at-point-p (section-type)
+  "Return non-nil if point is on a SECTION-TYPE section."
+  (magit-section-value-if section-type))
+
+(defvar-keymap jira-subtask-section-map
+  :doc "Keymap for Jira subtask sections."
+  "<RET>" (lambda () (interactive)
+            (jira-detail--open-related-issue-at-point 'jira-subtask-section))
+  "o" (lambda () (interactive)
+        (jira-detail--open-related-issue-in-browser 'jira-subtask-section)))
+
+(defclass jira-subtask-section (magit-section)
+  ((keymap :initform 'jira-subtask-section-map)))
+
+(defvar-keymap jira-linked-issue-section-map
+  :doc "Keymap for Jira linked issue sections."
+  "<RET>" (lambda () (interactive)
+            (jira-detail--open-related-issue-at-point 'jira-linked-issue-section))
+  "o" (lambda () (interactive)
+        (jira-detail--open-related-issue-in-browser 'jira-linked-issue-section)))
+
+(defclass jira-linked-issue-section (magit-section)
+  ((keymap :initform 'jira-linked-issue-section-map)))
+
+(defun jira-detail--subtask-at-point-p ()
+  "Return non-nil if point is on a subtask section."
+  (jira-detail--related-issue-at-point-p 'jira-subtask-section))
+
+(defun jira-detail--linked-issue-at-point-p ()
+  "Return non-nil if point is on a linked issue section."
+(jira-detail--related-issue-at-point-p 'jira-linked-issue-section))
 
 (defvar-keymap jira-attachment-section-map
   :doc "Keymap for Jira attachment sections."
@@ -435,7 +485,7 @@ This is a shared function used by both subtasks and linked issues."
     ;; Bind these so `normal-mode' will check the buffer contents
     ;; instead of just looking for a -*- line.
     (let ((buffer-file-name (file-name-concat temporary-file-directory
-                                             name))
+                                              name))
           (default-directory temporary-file-directory))
       (normal-mode))
     (set-buffer-modified-p t)))
@@ -592,7 +642,6 @@ CALLBACK is called with the watchers data."
    ("O" "Open issue in browser"
     (lambda () (interactive) (jira-actions-open-issue jira-detail--current-key)))
    ("P" "Show parent issue" (lambda () (interactive) (jira-detail--show-parent-issue)))
-   ("S" "Add subtask" (lambda () (interactive) (jira-detail--create-subtask)))
    ("U" "Update issue field"
     (lambda () (interactive) (jira-detail--update-field)))
    ("w" "Update watchers" jira-detail--watchers-menu)
@@ -602,7 +651,25 @@ CALLBACK is called with the watchers data."
     (lambda () (interactive)
       (jira-actions-copy-issues-id-to-clipboard jira-detail--current-key)))
    ("g" "Refresh issue detail"
-    (lambda () (interactive) (jira-detail-show-issue jira-detail--current-key)))])
+    (lambda () (interactive) (jira-detail-show-issue jira-detail--current-key)))
+   ("S" "Add subtask"
+    (lambda () (interactive) (jira-detail--create-subtask)))]
+  [:if jira-detail--subtask-at-point-p
+   "Subtask at point"
+   ("RET" "Open subtask"
+    (lambda () (interactive)
+      (jira-detail--open-related-issue-at-point 'jira-subtask-section)))
+   ("o" "Open subtask in browser"
+    (lambda () (interactive)
+      (jira-detail--open-related-issue-in-browser 'jira-subtask-section)))]
+  [:if jira-detail--linked-issue-at-point-p
+   "Linked issue at point"
+   ("RET" "Open linked issue"
+    (lambda () (interactive)
+        (jira-detail--open-related-issue-at-point 'jira-linked-issue-section)))
+   ("o" "Open linked issue in browser"
+    (lambda () (interactive)
+      (jira-detail--open-related-issue-in-browser 'jira-linked-issue-section)))])
 
 (defvar jira-detail-changed-hook nil
   "Hook run after a Jira issue has been changed in jira-detail-mode.")
@@ -635,6 +702,7 @@ CALLBACK is called with the watchers data."
     (define-key map (kbd "g")
 		(lambda () "Refresh issue detail"
 		  (interactive) (jira-detail-show-issue jira-detail--current-key)))
+    (define-key map (kbd "h") 'jira-detail--actions-menu)
     (define-key map (kbd "P")
 		(lambda () "Show parent issue"
 		  (interactive) (jira-detail--show-parent-issue)))
